{
    "Parameters": {
    "SSHLocation": {
      "Description": " The IP address source range allowed SSH access to defined EC2 instances",
      "Type": "String",
      "MinLength": "9",
      "MaxLength": "18",
      "Default": "{{ allowed_cidr }}",
      "AllowedPattern": "(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})\\.(\\d{1,3})/(\\d{1,2})",
      "ConstraintDescription": "must be a valid IP CIDR range of the form x.x.x.x/x."
    },
    "InstanceType": {
      "Description": "WebServer EC2 instance type",
      "Type": "String",
      "Default": "{{ instance_type }}",
      "AllowedValues": [
        "t2.micro"
      ],
      "ConstraintDescription": "must be a valid EC2 instance type."
    },
    "KeyName": {
      "Description": "Name of an existing EC2 KeyPair to allow SSH access to defined instances",
      "Type": "String",
      "Default": "{{ keyname }}"
    },
    "VPC": {
      "Description": "VpcId of the VPC to launch this instance in",
      "Type": "String",
      "Default": "{{ vpc }}"
    },
    "AMI": {
      "Description": "The ID of the AMI to lauch",
      "Type": "String",
      "Default": "{{ ami }}"
    },
    "Subnet": {
      "Description": "Subnet within the VPC to launch the instance",
      "Type": "String",
      "Default": "{{ subnet }}"
    }
}
}
