resources:
    {# A dummy role that does not give permission to do anything #}
    DummyRole:
        Type: 'AWS::IAM::Role'
        Properties:
            AssumeRolePolicyDocument:
                Version: '2012-10-17'
                Statement:
                    - Effect: Allow
                      Principal:
                          Service: 'lambda.amazonaws.com'
                      Action: 'sts:AssumeRole'
            Path: '/humilis/'
            Policies: []
